@@ -10,7 +10,7 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-from . import main
+from .core import main
 
 
 if __name__ == '__main__':
